from plasTeX.Renderers.XHTML import _Renderer

class S5(_Renderer):
    """ Renderer for S5 documents (intended for Beamer classes) """

Renderer = S5 
